@@ -5,7 +5,6 @@ from slippi.game import Game
 
 from ..parse import Parser
 from ..parse.parsers import matchup, month, stage, year
-from ..parse.utils import ParseError
 
 Ordering = Sequence[Parser]
 
@@ -13,12 +12,9 @@ default_ordering = (year, month, matchup, stage)
 
 
 def build_parent(game: Game, ordering: Ordering = default_ordering) -> Path:
-    try:
-        parent = Path()
+    parent = Path()
 
-        for parser in ordering:
-            parent /= str(parser(game))
+    for parser in ordering:
+        parent /= str(parser(game))
 
-        return parent
-    except ParseError:
-        return Path("Error")
+    return parent
